from setuptools import setup, find_packages

setup(
    name='zork-manager',
    version='0.1.0',
    license='MIT',
    author="Alex Vergara",
    author_email='pyzyryab@tutanota.com',
    packages=find_packages('zork'),
    package_dir={'': 'zork'},
    url='https://github.com/Pyzyryab/Zork',
    keywords='C++ project manager',
    install_requires=[
        #   '',
      ],
)
